import pygame
from pygame.locals import *
from sys import exit

SCROLLSPEED = 4
FIGHTERUPDOWN = 5


class Player(pygame.sprite.Sprite):

    def __init__(self, img):#img is string
        self.speed = SCROLLSPEED
        self.image = makeImage(img, True, 0, 5)
        self.x = 100
        self.y = 300
        self.hp = 100
        left = self.x - self.image.get_width()/2
        top = self.y - self.image.get_height()/2
        self.rect = pygame.Rect(left, top,
                                self.image.get_width(),
                                self.image.get_height())

    def draw(self, screen):
        screen.blit(self.image, self.rect)

    def move(self, direction):#0 is up, 1 is right etc.
        if direction == 0 and self.rect.top > FIGHTERUPDOWN:
            self.rect = self.rect.move(0, -self.speed)
        elif direction == 1 and self.rect.right < 1000 - FIGHTERUPDOWN:
            self.rect = self.rect.move(self.speed, 0)
        elif direction == 2 and self.rect.bottom < 600 -FIGHTERUPDOWN:
            self.rect = self.rect.move(0,  self.speed)
        elif self.rect.left > FIGHTERUPDOWN:
            self.rect = self.rect.move(-self.speed, 0)

    def getPointsForCollideChecking(self):
        return ((self.rect.left,self.rect.top),(self.rect.left,self.rect.bottom),(self.rect.right,self.rect.top),(self.rect.right,self.rect.bottom))

class BG(pygame.sprite.Sprite):

    def __init__(self, img):
        self.speed = SCROLLSPEED
        self.image = makeImage(img, False)
        left = 0
        top = 0
        self.rect = pygame.Rect(left, top,
                                self.image.get_width(),
                                self.image.get_height())

    def draw(self, screen):
        screen.blit(self.image, self.rect)

    def move(self):
        self.rect = self.rect.move(-self.speed, 0)

class BGStat(pygame.sprite.Sprite):

    def __init__(self, img):
        self.image = makeImage(img, False)
        left = 0
        top = 0
        self.rect = pygame.Rect(left, top,
                                self.image.get_width(),
                                self.image.get_height())

    def draw(self, screen):
        screen.blit(self.image, self.rect)


def titleLoop(clock, screen):
    pass

def mainLoop(clock, screen):

    keys = []

    p = Player("ship.png")
    bg = BG('map.png')

    while True:
        for event in pygame.event.get():
            if event.type == QUIT:
                exit()
            elif event.type == KEYDOWN:
                if event.key == K_UP:
                    keys += [0]
                elif event.key == K_RIGHT:
                    keys += [1]
                elif event.key == K_DOWN:
                    keys += [2]
                elif event.key == K_LEFT:
                    keys += [3]
            elif event.type == KEYUP:
                if event.key == K_UP and 0 in keys:
                    keys.remove(0)
                if event.key == K_RIGHT and 1 in keys:
                    keys.remove(1)
                elif event.key == K_DOWN and 2 in keys:
                    keys.remove(2)
                if event.key == K_LEFT and 3 in keys:
                    keys.remove(3)

        for key in keys:
            p.move(key)

        bg.move()

        bg.draw(screen)

        for point in p.getPointsForCollideChecking():
            if 0 < point[0] < 1000 and 0 < point[1] < 600:
                if screen.get_at(point) == pygame.Color("Black"):
                    return False

        if bg.rect.right <= 600:
            print("test")
            return True
        
        p.draw(screen)

        pygame.display.update()

        clock.tick(30)

        

        
            

def cutsceneLoop(clock, screen, imagelist, framelist):
    tick = 0
    curimg = BGStat(imagelist[0])
    while True:
        for event in pygame.event.get():
            if event.type == QUIT:
                exit()
            elif event.type == KEYDOWN:
                return

        if tick == framelist[0]:
            if len(framelist) == 1:
                return
            tick = 0
            framelist.pop(0)
            imagelist.pop(0)
            curimg = BGStat(imagelist[0])

        curimg.draw(screen)
        tick += 1

        pygame.display.update()
        clock.tick(30)

        

def makeImage(image, colorkey = True, x = 0, y = 0):
    image = pygame.image.load(image)
    image = image.convert()
    if colorkey:
        image.set_colorkey(image.get_at((x,y)))
    return image

pygame.mixer.pre_init(44100, 16, 2, 4096)
pygame.init()
screen = pygame.display.set_mode((1000, 600))
pygame.display.set_caption('Space Fighter Thingy!') ###new Title!

clock = pygame.time.Clock()


cutsceneLoop(clock, screen, ['start1.png', 'start2.png','start3.png','start4.png','start5.png','start6.png','start7.png','start8.png','start9.png','start10.png'], [60]*5 + [100]*5)
while True:
    if mainLoop(clock, screen):
        cutsceneLoop(clock, screen, ['dead1.png', 'dead2.png','dead3.png','dead4.png','dead5.png','dead6.png','dead7.png','dead8.png','dead9.png','dead10.png','dead11.png','dead12.png','dead13png'], [60]*13)
        break
    else:
        cutsceneLoop(clock, screen, ['youlose1.png','youlose2.png','youlose3.png','youlose4.png'],[60,60,60,160])
